powered by
Intervals are measured in standard deviations on either side of the mean.
chop_mean_sd(x, sds = 1:3, ..., raw = FALSE, sd = deprecated())brk_mean_sd(sds = 1:3, sd = deprecated())tab_mean_sd(x, sds = 1:3, ..., raw = FALSE)
brk_mean_sd(sds = 1:3, sd = deprecated())
tab_mean_sd(x, sds = 1:3, ..., raw = FALSE)
chop_* functions return a factor of the same length as x.
chop_*
factor
x
brk_* functions return a function to create breaks.
brk_*
function
breaks
tab_* functions return a contingency table().
tab_*
table()
A vector.
Positive numeric vector of standard deviations.
Passed to chop().
chop()
Logical. Use raw values in labels?
In version 0.7.0, these functions changed to specifying sds as a vector. To chop 1, 2 and 3 standard deviations around the mean, write chop_mean_sd(x, sds = 1:3) instead of chop_mean_sd(x, sd = 3).
sds
chop_mean_sd(x, sds = 1:3)
chop_mean_sd(x, sd = 3)
Other chopping functions: chop_equally(), chop_evenly(), chop_fn(), chop_n(), chop_proportions(), chop_quantiles(), chop_width(), chop(), fillet()
chop_equally()
chop_evenly()
chop_fn()
chop_n()
chop_proportions()
chop_quantiles()
chop_width()
fillet()
chop_mean_sd(1:10) chop(1:10, brk_mean_sd()) tab_mean_sd(1:10)
Run the code above in your browser using DataLab