powered by
chop_proportions() chops x into proportions of its range, excluding infinite values.
chop_proportions()
x
proportions
chop_proportions(x, proportions, ..., raw = TRUE)brk_proportions(proportions)tab_proportions(x, proportions, ..., raw = TRUE)
brk_proportions(proportions)
tab_proportions(x, proportions, ..., raw = TRUE)
chop_* functions return a factor of the same length as x.
chop_*
factor
brk_* functions return a function to create breaks.
brk_*
function
breaks
tab_* functions return a contingency table().
tab_*
table()
A vector.
Numeric vector between 0 and 1: proportions of x's range. If proportions has names, these will be used for labels.
Passed to chop().
chop()
Logical. Use raw values in labels?
By default, labels show the raw numeric endpoints. To label intervals by the proportions, use raw = FALSE.
raw = FALSE
Other chopping functions: chop_equally(), chop_evenly(), chop_fn(), chop_mean_sd(), chop_n(), chop_quantiles(), chop_width(), chop(), fillet()
chop_equally()
chop_evenly()
chop_fn()
chop_mean_sd()
chop_n()
chop_quantiles()
chop_width()
fillet()
chop_proportions(0:10, c(0.2, 0.8)) chop_proportions(0:10, c(Low = 0, Mid = 0.2, High = 0.8))
Run the code above in your browser using DataLab