lbl_manual: Label chopped intervals in a user-defined sequence
Description
Usage
lbl_manual(sequence, fmt = "%s")
Value
A function that creates a vector of labels.
Arguments
sequence
A character vector of labels.
fmt
String, list or function. A format for break endpoints.
Formatting endpoints
If fmt is not NULL then it is used to format the endpoints.
If fmt is a string, then numeric endpoints will be formatted by
sprintf(fmt, breaks); other endpoints, e.g. Date objects, will be
formatted by format(breaks, fmt).
If fmt is a list, then it will be used as arguments to format.
If fmt is a function, it should take a vector of numbers (or other objects
that can be used as breaks) and return a character vector. It may be helpful
to use functions from the {scales} package, e.g. scales::label_comma().
Details
lbl_manual() is deprecated because it is little used and is not closely
related to the rest of the package. It also risks mislabelling intervals, e.g.
if intervals are extended.
lbl_manual() uses an arbitrary sequence to label
intervals. If the sequence is too short, it will be pasted with itself and
repeated.
See Also
Other labelling functions:
lbl_dash(),
lbl_discrete(),
lbl_endpoints(),
lbl_glue(),
lbl_intervals(),
lbl_midpoints(),
lbl_seq()